import { ComponentOptionsMixin, DefineComponent, PropType, StyleValue, Ref } from 'vue';

declare const App: DefineComponent<
  {
    
    /**
     * Component's HTML Element
     */
    component: {
      type: StringConstructor;
      default: 'div';
    };

    /**
     * App theme. If set to `'parent'` it will look for `ios` or `md` class on root `<html>` element, useful to use with parent framework like Framework7 or Ionic
     */
    theme: {
      type: PropType<'ios' | 'material' | 'parent'>;
      default: 'material';
    };

    /**
     * Include `dark:` variants (if dark theme is in use)
     */
    dark: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Enables touch ripple effect in Material theme. Allows to globally disable touch ripple for all components
     */
    touchRipple: {
      type: BooleanConstructor;
      default: true;
    };

    /**
     * Adds `safe-areas` class to the container. Should be enabled if app container is the full screen element to properly handle screen safe areas
     */
    safeAreas: {
      type: BooleanConstructor;
      default: true;
    };
  },
  () => JSX.Element,
  unknown,
  {},
  {},
  ComponentOptionsMixin,
  ComponentOptionsMixin,
  {
    
  }
>;

export default App;