import { ComponentOptionsMixin, DefineComponent, PropType, StyleValue, Ref } from 'vue';

declare const Block: DefineComponent<
  {
    
    /**
     * Component's HTML Element
     */
    component: {
      type: StringConstructor;
      default: 'div';
    };

    /**
     * Tailwind CSS margin class
     */
    margin: {
      type: StringConstructor;
      default: 'my-8';
    };

    /**
     * Tailwind CSS padding class
     */
    padding: {
      type: StringConstructor;
      default: 'py-4';
    };

    /**
     * Adds extra highlighting and padding block content. Overwrites `strongIos` and `strongMaterial` props
     */
    strong: {
      type: BooleanConstructor;
      default: undefined;
    };

    /**
     * Adds extra highlighting and padding block content in iOS theme
     */
    strongIos: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Adds extra highlighting and padding block content in Material theme
     */
    strongMaterial: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Makes block inset. Overwrites `insetIos` and `insetMaterial` props
     */
    inset: {
      type: BooleanConstructor;
      default: undefined;
    };

    /**
     * Makes block inset in iOS theme
     */
    insetIos: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Makes block inset in Material theme
     */
    insetMaterial: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Makes block outline. Overwrites `outlineIos` and `outlineMaterial` props
     */
    outline: {
      type: BooleanConstructor;
      default: undefined;
    };

    /**
     * Makes block outline in iOS theme
     */
    outlineIos: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Makes block outline in Material theme
     */
    outlineMaterial: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Removes hairlines and margins, useful for case nesting block within other blocks
     */
    nested: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Object with Tailwind CSS colors classes
     */
    colors: {
      type: PropType<{
    
        /**
         *
         * @default 'border-black border-opacity-20 dark:border-white dark:border-opacity-15'
         */
        outlineIos?: string;
        /**
         *
         * @default 'border-md-light-outline border-md-dark-outline'
         */
        outlineMaterial?: string;
        /**
         *
         * @default `bg-ios-light-surface-1 dark:bg-ios-dark-surface-1'
         */
        strongBgIos?: string;
        /**
         *
         * @default 'bg-md-light-surface-1 dark:bg-md-dark-surface-1'
         */
        strongBgMaterial?: string;
        /**
         *
         * @default '''
         */
        textIos?: string;
        /**
         *
         * @default 'text-md-light-on-surface dark:text-md-dark-on-surface'
         */
        textMaterial?: string;
      
      }>;
      
    };
  },
  () => JSX.Element,
  unknown,
  {},
  {},
  ComponentOptionsMixin,
  ComponentOptionsMixin,
  {
    
  }
>;

export default Block;