import { ComponentOptionsMixin, DefineComponent, PropType, StyleValue, Ref } from 'vue';

declare const Button: DefineComponent<
  {
    
    /**
     * Component's HTML Element
     */
    component: {
      type: StringConstructor;
      default: 'button';
    };

    /**
     * Link's `href` attribute, when specified will also be rendered as `<a>` element
     */
    href: {
      type: StringConstructor;
      
    };

    /**
     * Makes button outline. Overwrites `outlineIos` and `outlineMaterial` props
     */
    outline: {
      type: BooleanConstructor;
      default: undefined;
    };

    /**
     * Makes button outline in iOS theme
     */
    outlineIos: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Makes button outline in Material theme
     */
    outlineMaterial: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Makes button in clear style (without fill color). Overwrites `clearIos` and `clearMaterial` props
     */
    clear: {
      type: BooleanConstructor;
      default: undefined;
    };

    /**
     * Makes button in clear style (without fill color) in iOS theme
     */
    clearIos: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Makes button in clear style (without fill color) in Material theme
     */
    clearMaterial: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Makes button in tonal style (with semitransparent fill color). Overwrites `tonalIos` and `tonalMaterial` props
     */
    tonal: {
      type: BooleanConstructor;
      default: undefined;
    };

    /**
     * Makes button in tonal style (with semitransparent fill color) in iOS theme
     */
    tonalIos: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Makes button in tonal style (with semitransparent fill color) in Material theme
     */
    tonalMaterial: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Makes button rounded. Overwrites `roundedIos` and `roundedMaterial` props
     */
    rounded: {
      type: BooleanConstructor;
      default: undefined;
    };

    /**
     * Makes button rounded in iOS theme
     */
    roundedIos: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Makes button rounded in Material theme
     */
    roundedMaterial: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Makes button small. Overwrites `smallIos` and `smallMaterial` props
     */
    small: {
      type: BooleanConstructor;
      default: undefined;
    };

    /**
     * Makes button small in iOS theme
     */
    smallIos: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Makes button small in Material theme
     */
    smallMaterial: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Makes button large. Overwrites `largeIos` and `largeMaterial` props
     */
    large: {
      type: BooleanConstructor;
      default: undefined;
    };

    /**
     * Makes button large in iOS theme
     */
    largeIos: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Makes button large in Material theme
     */
    largeMaterial: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Makes button raised (with shadow). Overwrites `raisedIos` and `raisedMaterial` props
     */
    raised: {
      type: BooleanConstructor;
      default: undefined;
    };

    /**
     * Makes button raised (with shadow) in iOS theme
     */
    raisedIos: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Makes button raised (with shadow) in Material theme
     */
    raisedMaterial: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Makes button inline (e.g. `display: inline-flex`)
     */
    inline: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Renders segmented button, same as `<SegmentedButton>`
     */
    segmented: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Renders segmented strong button, same as `<SegmentedButton strong>`
     */
    segmentedStrong: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Renders segmented active button, same as `<SegmentedButton active>`
     */
    segmentedActive: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Enables touch ripple effect in Material theme
     */
    touchRipple: {
      type: BooleanConstructor;
      default: true;
    };

    /**
     * Makes button disabled
     */
    disabled: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Object with Tailwind CSS colors classes
     */
    colors: {
      type: PropType<{
    
        /**
         *
         * @default 'active:bg-primary'
         */
        activeBgIos?: string;
        /**
         *
         * @default ''
         */
        activeBgMaterial?: string;
        /**
         *
         * @default 'text-primary'
         */
        textIos?: string;
        /**
         *
         * @default 'text-md-light-primary dark:text-md-dark-primary'
         */
        textMaterial?: string;
        /**
         *
         * @default 'text-white'
         */
        fillTextIos?: string;
        /**
         *
         * @default 'text-md-light-on-primary dark:text-md-dark-on-primary'
         */
        fillTextMaterial?: string;
        /**
         *
         * @default 'active:bg-ios-primary-shade'
         */
        fillActiveBgIos?: string;
        /**
         *
         * @default ''
         */
        fillActiveBgMaterial?: string;
        /**
         *
         * @default 'bg-primary'
         */
        fillBgIos?: string;
        /**
         *
         * @default 'bg-md-light-primary dark:bg-md-dark-primary'
         */
        fillBgMaterial?: string;
        /**
         *
         * @default 'touch-ripple-white dark:touch-ripple-primary'
         */
        fillTouchRipple?: string;
        /**
         *
         * @default 'border-primary'
         */
        outlineBorderIos?: string;
        /**
         *
         * @default 'border-md-light-outline dark:border-md-dark-outline'
         */
        outlineBorderMaterial?: string;
        /**
         *
         * @default 'bg-primary'
         */
        tonalBgIos?: string;
        /**
         *
         * @default 'bg-md-light-secondary-container dark:bg-md-dark-secondary-container'
         */
        tonalBgMaterial?: string;
        /**
         *
         * @default 'text-primary'
         */
        tonalTextIos?: string;
        /**
         *
         * @default 'text-md-light-on-secondary-container dark:text-md-dark-on-secondary-container'
         */
        tonalTextMaterial?: string;
        /**
         *
         * @default 'touch-ripple-primary'
         */
        touchRipple?: string;
        /**
         *
         * @default 'text-black text-opacity-30 dark:text-white dark:text-opacity-30'
         */
        disabledText?: string;
        /**
         *
         * @default 'bg-black bg-opacity-10 dark:bg-white dark:bg-opacity-10'
         */
        disabledBg?: string;
        /**
         *
         * @default 'border-black border-opacity-10 dark:border-white dark:border-opacity-10'
         */
        disabledBorder?: string;
      
      }>;
      
    };
  },
  () => JSX.Element,
  unknown,
  {},
  {},
  ComponentOptionsMixin,
  ComponentOptionsMixin,
  {
    
  }
>;

export default Button;