import { ComponentOptionsMixin, DefineComponent, PropType, StyleValue, Ref } from 'vue';

declare const List: DefineComponent<
  {
    
    /**
     * Component's HTML Element
     */
    component: {
      type: StringConstructor;
      default: 'div';
    };

    /**
     * Tailwind CSS margin class
     */
    margin: {
      type: StringConstructor;
      default: 'my-8';
    };

    /**
     * Renders dividers (borders) between list items, overwrites `dividersIos` and `dividersMaterial`
     */
    dividers: {
      type: BooleanConstructor;
      default: undefined;
    };

    /**
     * Renders dividers (borders) between list items in iOS theme
     */
    dividersIos: {
      type: BooleanConstructor;
      default: true;
    };

    /**
     * Renders dividers (borders) between list items in Material theme
     */
    dividersMaterial: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Adds extra highlighting. Overwrites `strongIos` and `strongMaterial`
     */
    strong: {
      type: BooleanConstructor;
      default: undefined;
    };

    /**
     * Adds extra highlighting in iOS theme
     */
    strongIos: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Adds extra highlighting in Material theme
     */
    strongMaterial: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Makes list block inset. Overwrites `insetIos` and `insetMaterial`
     */
    inset: {
      type: BooleanConstructor;
      default: undefined;
    };

    /**
     * Makes list block inset in iOS theme
     */
    insetIos: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Makes list block inset in Material theme
     */
    insetMaterial: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Renders list outer borders. Overwrites `outlineIos` and `outlineMaterial`
     */
    outline: {
      type: BooleanConstructor;
      default: undefined;
    };

    /**
     * Renders list outer borders in iOS theme
     */
    outlineIos: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Renders list outer borders in Material theme
     */
    outlineMaterial: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Removes hairlines/dividers and margins, useful for case nesting list block within other blocks
     */
    nested: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Renders list as Menu List (same as `<MenuList>`)
     */
    menuList: {
      type: BooleanConstructor;
      
    };

    /**
     * Object with Tailwind CSS colors classes
     */
    colors: {
      type: PropType<{
    
        /**
         *
         * @default 'border-black border-opacity-20 dark:border-white dark:border-opacity-15'
         */
        outlineIos?: string;
        /**
         *
         * @default 'border-md-light-outline border-md-dark-outline'
         */
        outlineMaterial?: string;
        /**
         *
         * @default 'bg-ios-light-surface-1 dark:bg-ios-dark-surface-1'
         */
        strongBgIos?: string;
        /**
         *
         * @default 'bg-md-light-surface-1 dark:bg-md-dark-surface-1'
         */
        strongBgMaterial?: string;
      
      }>;
      
    };
  },
  () => JSX.Element,
  unknown,
  {},
  {},
  ComponentOptionsMixin,
  ComponentOptionsMixin,
  {
    
  }
>;

export default List;