import { ComponentOptionsMixin, DefineComponent, PropType, StyleValue, Ref } from 'vue';

declare const ListInput: DefineComponent<
  {
    
    /**
     * Component's HTML Element
     */
    component: {
      type: StringConstructor;
      default: 'li';
    };

    /**
     * Label content
     */
    label: {
      type: StringConstructor;
      
    };

    /**
     * Renders outline-style input (with border around), overwrites `outlineIos` and `outlineMaterial`
     */
    outline: {
      type: BooleanConstructor;
      default: undefined;
    };

    /**
     * Renders outline-style input (with border around) in iOS theme
     */
    outlineIos: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Renders outline-style input (with border around) in Material theme
     */
    outlineMaterial: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Makes floating label
     */
    floatingLabel: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Content of the input "info"
     */
    info: {
      type: StringConstructor;
      
    };

    /**
     * Content of the input "error"
     */
    error: {
      type: PropType<string | boolean>;
      
    };

    /**
     * Adds input clear button
     */
    clearButton: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Renders additional dropdown icon (useful to use with `select` inputs)
     */
    dropdown: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Input id attribute
     */
    inputId: {
      type: StringConstructor;
      
    };

    /**
     * Additional input classes
     */
    inputStyle: {
      type: PropType<StyleValue>;
      
    };

    /**
     * Additional input styles
     */
    inputClass: {
      type: StringConstructor;
      
    };

    /**
     * Input name
     */
    name: {
      type: StringConstructor;
      
    };

    /**
     * Input value
     */
    value: {
      type: any;
      
    };

    /**
     * Input type
     */
    type: {
      type: StringConstructor;
      default: 'text';
    };

    /**
     * Value of input's native "inputmode" attribute
     */
    inputmode: {
      type: StringConstructor;
      
    };

    /**
     * Marks input as readonly
     */
    readonly: {
      type: BooleanConstructor;
      
    };

    /**
     * Marks input as required
     */
    required: {
      type: BooleanConstructor;
      
    };

    /**
     * Marks input as disabled
     */
    disabled: {
      type: BooleanConstructor;
      
    };

    /**
     * Input placeholder
     */
    placeholder: {
      type: PropType<string | number>;
      
    };

    /**
     * Value of input's native "size" attribute
     */
    size: {
      type: PropType<string | number>;
      
    };

    /**
     * Value of input's native "accept" attribute
     */
    accept: {
      type: PropType<string | number>;
      
    };

    /**
     * Value of input's native "autoComplete" attribute
     */
    autocomplete: {
      type: StringConstructor;
      
    };

    /**
     * Value of input's native "autocorrect" attribute
     */
    autocorrect: {
      type: StringConstructor;
      
    };

    /**
     * Value of input's native "autocapitalize" attribute
     */
    autocapitalize: {
      type: StringConstructor;
      
    };

    /**
     * Value of input's native "spellcheck" attribute
     */
    spellcheck: {
      type: StringConstructor;
      
    };

    /**
     * Value of input's native "autofocus" attribute
     */
    autofocus: {
      type: BooleanConstructor;
      
    };

    /**
     * Value of input's native "autosave" attribute
     */
    autosave: {
      type: StringConstructor;
      
    };

    /**
     * Value of input's native "max" attribute
     */
    max: {
      type: PropType<string | number>;
      
    };

    /**
     * Value of input's native "min" attribute
     */
    min: {
      type: PropType<string | number>;
      
    };

    /**
     * Value of input's native "step" attribute
     */
    step: {
      type: PropType<string | number>;
      
    };

    /**
     * Value of input's native "maxlength" attribute
     */
    maxlength: {
      type: PropType<string | number>;
      
    };

    /**
     * Value of input's native "minlength" attribute
     */
    minlength: {
      type: PropType<string | number>;
      
    };

    /**
     * Value of input's native "multiple" attribute
     */
    multiple: {
      type: BooleanConstructor;
      
    };

    /**
     * Value of input's native "pattern" attribute
     */
    pattern: {
      type: StringConstructor;
      
    };

    /**
     * Value of input's native "tabindex" attribute
     */
    tabindex: {
      type: PropType<string | number>;
      
    };

    /**
     * Object with Tailwind CSS colors classes
     */
    colors: {
      type: PropType<{
    
        /**
         *
         * @default ''
         */
        bgIos?: string;
        /**
         *
         * @default 'bg-md-light-surface-variant dark:bg-md-dark-surface-variant'
         */
        bgMaterial?: string;
        /**
         *
         * @default 'border-black border-opacity-30 dark:border-white dark:border-opacity-30'
         */
        outlineBorderIos?: string;
        /**
         *
         * @default 'border-primary'
         */
        outlineBorderFocusIos?: string;
        /**
         *
         * @default 'border-md-light-on-surface dark:border-md-dark-on-surface'
         */
        outlineBorderMaterial?: string;
        /**
         *
         * @default 'border-md-light-primary dark:border-md-dark-primary'
         */
        outlineBorderFocusMaterial?: string;
        /**
         *
         * @default 'bg-ios-light-surface-1 dark:bg-ios-dark-surface-1'
         */
        outlineLabelBgIos?: string;
        /**
         *
         * @default 'bg-md-light-surface dark:bg-md-dark-surface'
         */
        outlineLabelBgMaterial?: string;
        /**
         *
         * @default ''
         */
        labelTextIos?: string;
        /**
         *
         * @default ''
         */
        labelTextFocusIos?: string;
        /**
         *
         * @default 'text-md-light-on-surface-variant dark:text-md-dark-on-surface-variant'
         */
        labelTextMaterial?: string;
        /**
         *
         * @default 'text-md-light-primary dark:text-md-dark-primary'
         */
        labelTextFocusMaterial?: string;
        /**
         *
         * @default 'text-red-500'
         */
        errorText?: string;
        /**
         *
         * @default 'border-red-500'
         */
        errorBorder?: string;
      
      }>;
      
    };
  },
  () => JSX.Element,
  unknown,
  {},
  {},
  ComponentOptionsMixin,
  ComponentOptionsMixin,
  {
    
    /**
     * `input` event handler
     */
    input: (e: any) => void;
    

    /**
     * `change` event handler
     */
    change: (e: any) => void;
    

    /**
     * `focus` event handler
     */
    focus: (e: any) => void;
    

    /**
     * `blur` event handler
     */
    blur: (e: any) => void;
    

    /**
     * `clear` event handler
     */
    clear: (e: any) => void;
    
  }
>;

export default ListInput;