import { ComponentOptionsMixin, DefineComponent, PropType, StyleValue, Ref } from 'vue';

declare const Navbar: DefineComponent<
  {
    
    /**
     * Component's HTML Element
     */
    component: {
      type: StringConstructor;
      default: 'div';
    };

    /**
     * Tailwind CSS class for font size in iOS theme
     */
    fontSizeIos: {
      type: StringConstructor;
      default: 'text-[17px]';
    };

    /**
     * Tailwind CSS class for font size in Material theme
     */
    fontSizeMaterial: {
      type: StringConstructor;
      default: 'text-[16px]';
    };

    /**
     * Tailwind CSS class for navbar title font size in iOS theme
     */
    titleFontSizeIos: {
      type: StringConstructor;
      default: 'text-[17px]';
    };

    /**
     * Tailwind CSS class for navbar title font size in Material theme
     */
    titleFontSizeMaterial: {
      type: StringConstructor;
      default: 'text-[22px]';
    };

    /**
     * Tailwind CSS class for medium-sized navbar title font size in iOS theme
     */
    titleMediumFontSizeIos: {
      type: StringConstructor;
      default: 'text-[24px]';
    };

    /**
     * Tailwind CSS class for medium-sized navbar title font size in Material theme
     */
    titleMediumFontSizeMaterial: {
      type: StringConstructor;
      default: 'text-[24px]';
    };

    /**
     * Tailwind CSS class for large-sized navbar title font size in iOS theme
     */
    titleLargeFontSizeIos: {
      type: StringConstructor;
      default: 'text-[34px]';
    };

    /**
     * Tailwind CSS class for large-sized navbar title font size in Material theme
     */
    titleLargeFontSizeMaterial: {
      type: StringConstructor;
      default: 'text-[28px]';
    };

    /**
     * Additional class to add on Navbar's "background" element
     */
    bgClass: {
      type: StringConstructor;
      
    };

    /**
     * Additional class to add on Navbar's "inner" element
     */
    innerClass: {
      type: StringConstructor;
      
    };

    /**
     * Additional class to add on Navbar's "left" element
     */
    leftClass: {
      type: StringConstructor;
      
    };

    /**
     * Additional class to add on Navbar's "title" element
     */
    titleClass: {
      type: StringConstructor;
      
    };

    /**
     * Additional class to add on Navbar's "subtitle" element
     */
    subtitleClass: {
      type: StringConstructor;
      
    };

    /**
     * Additional class to add on Navbar's "right" element
     */
    rightClass: {
      type: StringConstructor;
      
    };

    /**
     * Additional class to add on Navbar's "subnavbar" element
     */
    subnavbarClass: {
      type: StringConstructor;
      
    };

    /**
     * Makes Navbar background translucent (with `backdrop-filter: blur`) in iOS theme
     */
    translucent: {
      type: BooleanConstructor;
      default: true;
    };

    /**
     * Renders outer hairlines (borders). If not specified, will be enabled for iOS theme
     */
    outline: {
      type: BooleanConstructor;
      default: undefined;
    };

    /**
     * Renders medium-sized navbar with extra row for medium-sized title which becomes usual size on scroll
     */
    medium: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Renders large-sized navbar with extra row for large-sized title which becomes usual size on scroll
     */
    large: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Renders transparent navbar which becomes opaque on scroll
     */
    transparent: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Element required for correct "collapse" functionality for medium/large/transparent Navbar. If not specified, it will use Navbar's parent element
     */
    scrollEl: {
      type: any;
      default: undefined;
    };

    /**
     * Makes centered navbar title. If not specified then it set it to center in iOS theme
     */
    centerTitle: {
      type: BooleanConstructor;
      default: undefined;
    };

    /**
     * Content of the Navbar's "left" area
     */
    left: {
      type: PropType<string | number>;
      
    };

    /**
     * Content of the Navbar's "title" area
     */
    title: {
      type: PropType<string | number>;
      
    };

    /**
     * Content of the Navbar's "subtitle" area
     */
    subtitle: {
      type: PropType<string | number>;
      
    };

    /**
     * Content of the Navbar's "right" area
     */
    right: {
      type: PropType<string | number>;
      
    };

    /**
     * Content of the Navbar's "subnavbar" area
     */
    subnavbar: {
      type: PropType<string | number>;
      
    };

    /**
     * Object with Tailwind CSS colors classes
     */
    colors: {
      type: PropType<{
    
        /**
         *
         * @default 'bg-ios-light-surface-2 dark:bg-ios-dark-surface-2'
         */
        bgIos?: string;
        /**
         *
         * @default 'bg-md-light-surface-2 dark:bg-md-dark-surface-2'
         */
        bgMaterial?: string;
        /**
         *
         * @default 'text-black dark:text-white'
         */
        textIos?: string;
        /**
         *
         * @default 'text-md-light-on-surface dark:text-md-dark-on-surface'
         */
        textMaterial?: string;
      
      }>;
      
    };
  },
  () => JSX.Element,
  unknown,
  {},
  {},
  ComponentOptionsMixin,
  ComponentOptionsMixin,
  {
    
  }
>;

export default Navbar;