import { ComponentOptionsMixin, DefineComponent, PropType, StyleValue, Ref } from 'vue';

declare const Stepper: DefineComponent<
  {
    
    /**
     * Component's HTML Element
     */
    component: {
      type: StringConstructor;
      default: 'div';
    };

    /**
     * Stepper value
     */
    // @ts-ignore
  value: {
      type: NumberConstructor;
      default: 0;
    };

    /**
     * Defines should it render <input> element or not
     */
    input: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Input type
     */
    inputType: {
      type: StringConstructor;
      default: 'text';
    };

    /**
     * Input placeholder
     */
    inputPlaceholder: {
      type: StringConstructor;
      
    };

    /**
     * Defines whether the stepper input is disabled or not
     */
    inputDisabled: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Defines whether the stepper input is read only or not
     */
    inputReadOnly: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Disables inner value container between stepper buttons
     */
    buttonsOnly: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Makes stepper round. Overwrites `roundedIos` and `roundedMaterial`
     */
    rounded: {
      type: BooleanConstructor;
      default: undefined;
    };

    /**
     * Makes stepper round in iOS theme
     */
    roundedIos: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Makes stepper round in Material theme
     */
    roundedMaterial: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Makes stepper small. Overwrites `smallIos` and `smallMaterial`
     */
    small: {
      type: BooleanConstructor;
      default: undefined;
    };

    /**
     * Makes stepper small in iOS theme
     */
    smallIos: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Makes stepper small in Material theme
     */
    smallMaterial: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Makes stepper large. Overwrites `largeIos` and `largeMaterial`
     */
    large: {
      type: BooleanConstructor;
      default: undefined;
    };

    /**
     * Makes stepper large in iOS theme
     */
    largeIos: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Makes stepper large in Material theme
     */
    largeMaterial: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Makes stepper raised (with shadow). Overwrites `raisedIos` and `raisedMaterial`
     */
    raised: {
      type: BooleanConstructor;
      default: undefined;
    };

    /**
     * Makes stepper raised (with shadow) in iOS theme
     */
    raisedIos: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Makes stepper raised (with shadow) in Material theme
     */
    raisedMaterial: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Makes stepper outline. Overwrites `outlineIos` and `outlineMaterial`
     */
    outline: {
      type: BooleanConstructor;
      default: undefined;
    };

    /**
     * Makes stepper outline in iOS theme
     */
    outlineIos: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Makes stepper outline in Material theme
     */
    outlineMaterial: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Enables touch ripple effect in Material theme
     */
    touchRipple: {
      type: BooleanConstructor;
      default: true;
    };

    /**
     * Object with Tailwind CSS colors classes
     */
    colors: {
      type: PropType<{
    
        /**
         *
         * @default 'active:bg-primary'
         */
        activeBgIos?: string;
        /**
         *
         * @default ''
         */
        activeBgMaterial?: string;
        /**
         *
         * @default 'text-primary'
         */
        textIos?: string;
        /**
         *
         * @default 'text-md-light-primary dark:text-md-dark-primary'
         */
        textMaterial?: string;
        /**
         *
         * @default 'text-white'
         */
        fillTextIos?: string;
        /**
         *
         * @default 'text-md-light-on-primary dark:text-md-dark-on-primary'
         */
        fillTextMaterial?: string;
        /**
         *
         * @default 'bg-primary'
         */
        fillBgIos?: string;
        /**
         *
         * @default 'bg-md-light-primary dark:bg-md-dark-primary'
         */
        fillBgMaterial?: string;
        /**
         *
         * @default 'active:bg-ios-primary-shade'
         */
        fillActiveBgIos?: string;
        /**
         *
         * @default ''
         */
        fillActiveBgMaterial?: string;
        /**
         *
         * @default 'touch-ripple-white dark:touch-ripple-primary'
         */
        fillTouchRipple?: string;
        /**
         *
         * @default 'border-primary'
         */
        outlineBorderIos?: string;
        /**
         *
         * @default 'border-md-light-outline dark:border-md-dark-outline'
         */
        outlineBorderMaterial?: string;
        /**
         *
         * @default 'touch-ripple-primary'
         */
        touchRipple?: string;
      
      }>;
      
    };
  },
  () => JSX.Element,
  unknown,
  {},
  {},
  ComponentOptionsMixin,
  ComponentOptionsMixin,
  {
    
    /**
     * Stepper input `input` handler
     */
    input: (e: any) => void;
    

    /**
     * Stepper input `change` handler
     */
    change: (e: any) => void;
    

    /**
     * Stepper input `focus` handler
     */
    focus: (e: any) => void;
    

    /**
     * Stepper input `blur` handler
     */
    blur: (e: any) => void;
    

    /**
     * Stepper "minus" button click handler
     */
    minus: (e: any) => void;
    

    /**
     * Stepper "plus" button click handler
     */
    plus: (e: any) => void;
    
  }
>;

export default Stepper;