import { ComponentOptionsMixin, DefineComponent, PropType, StyleValue, Ref } from 'vue';

declare const Toolbar: DefineComponent<
  {
    
    /**
     * Component's HTML Element
     */
    component: {
      type: StringConstructor;
      default: 'div';
    };

    /**
     * Makes Toolbar background translucent (with `backdrop-filter: blur`) in iOS theme
     */
    translucent: {
      type: BooleanConstructor;
      default: true;
    };

    /**
     * Additional class to add on Toolbar's "background" element
     */
    bgClass: {
      type: StringConstructor;
      
    };

    /**
     * Additional class to add on Toolbar's "inner" element
     */
    innerClass: {
      type: StringConstructor;
      
    };

    /**
     * Renders outer hairlines (borders). If not specified, will be enabled for iOS theme
     */
    outline: {
      type: BooleanConstructor;
      default: undefined;
    };

    /**
     * Enables tabbar, same as using `<Tabbar>` component
     */
    tabbar: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Enables tabbar with labels, same as using `<Tabbar labels>` component
     */
    tabbarLabels: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Enables tabbar with icons, same as using `<Tabbar icons>` component
     */
    tabbarIcons: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Enables top toolbar, in this case it renders border on shadows on opposite sides
     */
    top: {
      type: BooleanConstructor;
      default: false;
    };

    /**
     * Object with Tailwind CSS colors classes
     */
    colors: {
      type: PropType<{
    
        /**
         *
         * @default 'bg-ios-light-surface-2 dark:bg-ios-dark-surface-2'
         */
        bgIos?: string;
        /**
         *
         * @default 'bg-md-light-surface-2 dark:bg-md-dark-surface-2'
         */
        bgMaterial?: string;
        /**
         *
         * @default 'bg-primary'
         */
        tabbarHighlightBgIos?: string;
        /**
         *
         * @default 'bg-md-light-primary dark:bg-md-dark-primary'
         */
        tabbarHighlightBgMaterial?: string;
      
      }>;
      
    };
  },
  () => JSX.Element,
  unknown,
  {},
  {},
  ComponentOptionsMixin,
  ComponentOptionsMixin,
  {
    
  }
>;

export default Toolbar;